==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/member/zipcode.php <==
<?
///////////////////////////////////////////////////////////////////////////
// zipcode.php
// ȣ ˻ 
// 2005. 7. 19.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
//  ø   
//
// zipcode.htm Ų ۼϽ    ̸ ø 
// ֽʽÿ.
//
// form   ±׵
// ========================================================================
// name				: value		: 
// ========================================================================
// search_key		:			: ȣ ˻ Ű
// ========================================================================
//
//  µǴ ±
// ========================================================================
// <@ȣ> ... </@ȣ>	: ˻ ȣ  κ
//		<#ȣ>			: ˻ ȣ
//		<#âּ>	: â  ּ (/  )
//		<#ּ>				: ˻ ȣ  ּ
// ========================================================================
//
//  ±
// ========================================================================
// <!> ... </!˻>	: ˻ 쿡 ǥ
// 		<#˻>		: ˻
//		<@ȣ>	:  ȣ ϵ ˻  ǥõȴ.
// ========================================================================
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_lib.php";
require_once "../include/gc_output_lib.php";

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  Ȯ
//
// search_key	: ȣ ˻  ˻
// mode			: ⺻  ܿ  Ư ó ʿ ˷ִ 
///////////////////////////////////////////////////////////////////////////
if (!isset($search_key))
	$search_key = "";
if (!isset($mode))
	$mode = "";


//    ///////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// Ų  о
///////////////////////////////////////////////////////////////////////////
$zipcode_view = loadfile($member_skin."/zipcode.htm");


///////////////////////////////////////////////////////////////////////////
// ˻  
///////////////////////////////////////////////////////////////////////////
$list_arr = array();
$search_row = array();
if (!empty($search_key))
{
	// search_key '' ԵǾ   
	$modified_search_key = $search_key;
	if (substr($search_key, -2) != "")
		$modified_search_key .= "";

	// ˻   
	$search_query = "select * from zipcode"
				." where dong='$modified_search_key'";
	$search_row = gc_query($search_query);

///////////////////////////////////////////////////////////////////////////
//   
//
// {...}  key {...} ӿ    value Ͽ
// list_arr̶ 迭 . ̴ ½ÿ out_list ڷ δ.
///////////////////////////////////////////////////////////////////////////
	for ($i=0; $i<sizeof($search_row); $i++)
	{
		$major_addr = $search_row[$i]["sido"]." ".$search_row[$i]["gugun"]
				." ".$search_row[$i]["dong"];
		$detail_addr = $search_row[$i]["bunji"];

		$tmp_arr = array();
		$tmp_arr["<#ȣ>"]			= $search_row[$i]["zipcode"];
		$tmp_arr["<#âּ>"]	= $major_addr;
		$tmp_arr["<#ּ>"]				= $major_addr." ".$detail_addr;

		array_push($list_arr, $tmp_arr);
	}
} // end if (search_key)


//  κ //////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// ˻ 
//
// ˻  쿡 
///////////////////////////////////////////////////////////////////////////
$zipcode_view = out_list($list_arr, "<@ȣ>", "</@ȣ>"
		, $zipcode_view);
$zipcode_view = out_hiddentag("<!˻>", "</!˻>", $zipcode_view
		, $search_key);

///////////////////////////////////////////////////////////////////////////
// ü (δ ⼭  ȴ.)
///////////////////////////////////////////////////////////////////////////
print_all($top_file, $bottom_file, $zipcode_view);
?>

==> gc_board_0.09.01.tar.gz: gc_board_0.09.01/member/zipcode.php <==
<?
///////////////////////////////////////////////////////////////////////////
// zipcode.php
// ȣ ˻ 
// 2005. 8. 25.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
//  ø   
//
// zipcode.htm Ų ۼϽ    ̸ ø 
// ֽʽÿ.
//
// form   ±׵
// ========================================================================
// name				: value		: 
// ========================================================================
// search_key		:			: ȣ ˻ Ű
// ========================================================================
//
//  µǴ ±
// ========================================================================
// <@ȣ> ... </@ȣ>	: ˻ ȣ  κ
//		<#ȣ>			: ˻ ȣ
//		<#âּ>	: â  ּ (/  )
//		<#ּ>				: ˻ ȣ  ּ
// ========================================================================
//
//  ±
// ========================================================================
// <!> ... </!˻>	: ˻ 쿡 ǥ
// 		<#˻>		: ˻
//		<@ȣ>	:  ȣ ϵ ˻  ǥõȴ.
// ========================================================================
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_output_lib.php";

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  Ȯ
//
// search_key	: ȣ ˻  ˻
// mode			: ⺻  ܿ  Ư ó ʿ ˷ִ 
///////////////////////////////////////////////////////////////////////////
if (!isset($search_key))
	$search_key = "";
if (!isset($mode))
	$mode = "";


//    ///////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// Ų  о
///////////////////////////////////////////////////////////////////////////
$zipcode_view = loadfile($member_skin."/zipcode.htm");


///////////////////////////////////////////////////////////////////////////
// ˻  
///////////////////////////////////////////////////////////////////////////
$list_arr = array();
$search_row = array();
if (!empty($search_key))
{
	// ˻   
	$search_query = "select * from gc_zipcode"
				." where dong like '%$search_key%'"
				." or ri like '%$search_key%'"
				." or doseo like '%$search_key%'"
				." or building like '%$search_key%'";
	$search_row = gc_query($search_query);

///////////////////////////////////////////////////////////////////////////
//   
//
// {...}  key {...} ӿ    value Ͽ
// list_arr̶ 迭 . ̴ ½ÿ out_list ڷ δ.
///////////////////////////////////////////////////////////////////////////
	for ($i=0; $i<sizeof($search_row); $i++)
	{
		$out_zipcode = substr($search_row[$i]["zipcode"],0,3)."-"
				.substr($search_row[$i]["zipcode"],3,3);
		$major_addr = $search_row[$i]["sido"]." ".$search_row[$i]["gungu"]
				." ".$search_row[$i]["dong"];
		if (!empty($search_row[$i]["doseo"]))
			$major_addr .= " ".$search_row[$i]["doseo"];
		if (!empty($search_row[$i]["building"]))
			$major_addr .= " ".$search_row[$i]["building"];
		$full_addr = $search_row[$i]["full_addr"];

		$tmp_arr = array();
		$tmp_arr["<#ȣ>"]			= $out_zipcode;
		$tmp_arr["<#âּ>"]	= $major_addr;
		$tmp_arr["<#ּ>"]				= $full_addr;

		array_push($list_arr, $tmp_arr);
	}
} // end if (search_key)


//  κ //////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// ˻ 
//
// ˻  쿡 
///////////////////////////////////////////////////////////////////////////
$zipcode_view = out_list($list_arr, "<@ȣ>", "</@ȣ>"
		, $zipcode_view);
$zipcode_view = out_hiddentag("<!˻>", "</!˻>", $zipcode_view
		, $search_key);

///////////////////////////////////////////////////////////////////////////
// ü (δ ⼭  ȴ.)
///////////////////////////////////////////////////////////////////////////
print_all($top_file, $bottom_file, $zipcode_view);
?>
